@@ -14,9 +14,9 @@ def import_api_module(module_path: str):
     :param module_path: 'app.model'
     :return: None
     """
-    base_dir = str(pathlib.Path(__file__).parent.parent)
+    base_dir = str(pathlib.Path(__file__).resolve().parent.parent)
     path = str(pathlib.Path(base_dir, *module_path.split(".")))
-    for py_path in glob(f"{path}/**/*.py", recursive=True):
+    for py_path in glob(str(pathlib.Path(path, '**', '*.py')), recursive=True):
         py = (
             (".".join(py_path.split(base_dir)[1:]))
             .replace(".py", "")
